@@ -1,5 +1,5 @@
 /*
- * $Id: database.c,v 1.5 1999/03/07 08:36:40 dirk Exp $
+ * $Id: database.c,v 1.7 1999/05/05 16:34:20 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * obviously it won't contain track titles just after a CD is inserted.)
  */
 
-static char database_id[] = "$Id: database.c,v 1.5 1999/03/07 08:36:40 dirk Exp $";
+static char database_id[] = "$Id: database.c,v 1.7 1999/05/05 16:34:20 dirk Exp $";
 
 #define RCFILE "/.workmanrc"
 #define DBFILE "/.workmandb"
@@ -48,6 +48,7 @@ static char database_id[] = "$Id: database.c,v 1.5 1999/03/07 08:36:40 dirk Exp
 #include "include/wm_helpers.h"
 #include "include/wm_struct.h"
 #include "include/wm_cdinfo.h"
+#include "include/wm_cddb.h"
 #include "include/wm_index.h"
 #include "include/wm_database.h"
 
@@ -209,9 +210,7 @@ nomem:
  * XXX - could be more efficient about calling wm_strmcat() and strlen().
  */
 char *
-print_cdinfo(cd, prefs)
-	struct wm_cdinfo	*cd;
-	int		prefs;
+print_cdinfo(struct wm_cdinfo *cd, int prefs)
 {
 	int		i;
 	char		tempbuf[2000];	/* XXX - is this always big enough? */
@@ -357,7 +356,7 @@ print_cdinfo(cd, prefs)
 	}
 
 	return (cdibuf);
-}
+} /* print_cdinfo() */
 
 /*
  * Open the rcfile for reading or writing.
@@ -366,8 +365,7 @@ print_cdinfo(cd, prefs)
  *	mode		"r" or "w"
  */
 FILE *
-open_rcfile(name, mode)
-	char	*name, *mode;
+open_rcfile(char *name, char *mode)
 {
 	FILE		*fp;
 	struct stat	st;
@@ -414,6 +412,11 @@ open_rcfile(name, mode)
 	return (fp);
 }
 
+/*
+ *
+ * allocate and clear "trackmap".
+ *
+ */
 int *reset_tracks(void)
 {
     int i, j;
@@ -438,7 +441,7 @@ int *reset_tracks(void)
 		;
     }
     return trackmap;
-}
+} /* reset_tracks() */
 
 /*
  * Load a new-format database file, searching for a match with the currently
@@ -608,6 +611,80 @@ chomp:
 		}
 
 		/* Global mode stuff goes here */
+		else if (! strcmp(keyword, "cddbprotocol"))
+		{
+			getc(fp);
+			i = getc(fp);	/* only first letter is used */
+		        cddb.protocol = i == 'c' ? 1 : 
+		                        i == 'h' ? 2 : 3 ;
+			do
+				i = getc(fp);
+			while (i != '\n' && i != EOF);
+		}
+
+		else if (! strcmp(keyword, "cddbserver"))
+		{
+			getc(fp);	/* lose the space */
+			if (cddb.cddb_server[0])
+				do
+					i = getc(fp);
+				while (i != '\n' && i != EOF);
+			else
+			{
+				fgets(cddb.cddb_server, 
+				      sizeof(cddb.cddb_server), fp);
+				if ((i = strlen(cddb.cddb_server)))
+					cddb.cddb_server[i - 1] = '\0';
+			}
+		}
+
+		else if (! strcmp(keyword, "cddbmailadress"))
+		{
+			getc(fp);	/* lose the space */
+			if (cddb.mail_adress[0])
+				do
+					i = getc(fp);
+				while (i != '\n' && i != EOF);
+			else
+			{
+				fgets(cddb.mail_adress, 
+				      sizeof(cddb.mail_adress), fp);
+				if ((i = strlen(cddb.mail_adress)))
+					cddb.mail_adress[i - 1] = '\0';
+			}
+		}
+
+		else if (! strcmp(keyword, "cddbpathtocgi"))
+		{
+			getc(fp);	/* lose the space */
+			if (cddb.path_to_cgi[0])
+				do
+					i = getc(fp);
+				while (i != '\n' && i != EOF);
+			else
+			{
+				fgets(cddb.path_to_cgi, 
+				      sizeof(cddb.path_to_cgi), fp);
+				if ((i = strlen(cddb.path_to_cgi)))
+					cddb.path_to_cgi[i - 1] = '\0';
+			}
+		}
+
+		else if (! strcmp(keyword, "cddbproxy"))
+		{
+			getc(fp);	/* lose the space */
+			if (cddb.proxy_server[0])
+				do
+					i = getc(fp);
+				while (i != '\n' && i != EOF);
+			else
+			{
+				fgets(cddb.proxy_server, 
+				      sizeof(cddb.proxy_server), fp);
+				if ((i = strlen(cddb.proxy_server)))
+					cddb.proxy_server[i - 1] = '\0';
+			}
+		}
 
 		else if (! strcmp(keyword, "whendone"))
 		{
@@ -758,11 +835,11 @@ chomp:
                            we find the name, in hopes that we will recover
                            most, if not all, of the information from the
                            file. */
-//
-// nasty bug was here. Was it? BUGBUGBUG
-//
-//			 wipe_cdinfo(); 
-//			 trackmap = reset_tracks();
+/*
+ * nasty bug was here. Was it? BUGBUGBUG
+ *
+ *			 wipe_cdinfo(); 
+ */			 trackmap = reset_tracks();
 
 			getc(fp);	/* lose the space */
 			/* don't overwrite existing cd name. */
@@ -934,25 +1011,29 @@ plnomem:
         if (searching > 1) /* A near match has been found. Good enough. */
             searching = 0;
 
+        cddb_struct2cur();
 	return (! searching);
 
-}
+} /* search_db() */
 
 /*
  * Delay some amount of time without using interval timers.
  */
 void
-spinwheels(secs)
-	int	secs;
-{
+spinwheels(int secs) {
 	struct timeval	tv;
 
 	tv.tv_usec = 0;
 	tv.tv_sec = secs;
 	select(0, NULL, NULL, NULL, &tv);
-}
+} /* spinwheels() */
 
 /*
+ * lockit(fd, type)
+ *
+ * fd    file descriptor
+ * type  lock type
+ *
  * Lock a file.  Time out after a little while if we can't get a lock;
  * this usually means the locking system is broken.
  *
@@ -960,9 +1041,7 @@ spinwheels(secs)
  * this can result in the file not getting locked when it probably should.
  */
 int
-lockit(fd, type)
-	int	fd;
-	int	type;
+lockit(int fd, int type)
 {
 	struct flock	fl;
 	int		result, timer = 0;
@@ -989,7 +1068,7 @@ lockit(fd, type)
 	}
 
 	return (result);
-}
+} /* lockit */
 
 /*
  * Search all the database files and our personal preference file for
@@ -1004,6 +1083,8 @@ load( void )
 	int		dbfound = 0, *trklist, i;
 	unsigned long	dbpos;
 
+/* This is some kind of profiling code. I don't change it
+   to wm_lib_message() for now... */
 #ifdef DEBUG
 	long		t1, t2;
 	if( getenv( "WORKMAN_DEBUG" ) != NULL )
@@ -1094,7 +1175,7 @@ load( void )
 		fflush(stdout);
 	  }	
 #endif
-}
+} /* load() */
 
 /*
  * Load program settings from the rcfile.
@@ -1124,7 +1205,7 @@ load_settings( void )
 
 		fclose(fp);
 	}
-}
+} /* load_settings() */
 
 /*
  * save_globals()
@@ -1134,8 +1215,7 @@ load_settings( void )
  * been set by a previous scan.
  */
 void
-save_globals(fp)
-FILE *fp;
+save_globals(FILE *fp)
 {
 	char	*globes = NULL, *cdentry = NULL, temp[100];
 	long	curpos;
@@ -1144,6 +1224,53 @@ FILE *fp;
 	if (otherrc)
 		wm_strmcpy(&globes, otherrc);
 
+	if (cddb.protocol)
+	{
+		sprintf(temp, "cddbprotocol ");
+		switch(cddb.protocol)
+		{
+		 case 1: // cddbp
+		    sprintf(temp + strlen(temp), "cddbp\n");
+		    break;
+		 case 2: // http
+		    sprintf(temp + strlen(temp), "http\n");
+		    break;
+		 case 3: // proxy
+		    sprintf(temp + strlen(temp), "proxy\n");
+		    break;
+		 default:
+		}
+		wm_strmcat(&globes, temp);
+	    
+		if(cddb.mail_adress[0])
+	 	{
+			sprintf(temp,"cddbmailadress %s\n",
+				cddb.mail_adress);
+			wm_strmcat(&globes, temp);
+		}
+
+		if(cddb.cddb_server[0])
+	 	{
+			sprintf(temp,"cddbserver %s\n",
+				cddb.cddb_server);
+			wm_strmcat(&globes, temp);
+		}
+
+		if(cddb.path_to_cgi[0])
+	 	{
+			sprintf(temp,"cddbpathtocgi %s\n",
+				cddb.mail_adress);
+			wm_strmcat(&globes, temp);
+		}
+
+		if(cddb.proxy_server[0])
+	 	{
+			sprintf(temp,"cddbproxy %s\n",
+				cddb.mail_adress);
+			wm_strmcat(&globes, temp);
+		}
+	}
+
 	if (cur_stopmode == 1 || cur_stopmode == 2)
 	{
 		sprintf(temp, "whendone %s\n", cur_stopmode == 1 ? "repeat" :
@@ -1231,7 +1358,7 @@ FILE *fp;
 
 	while (globesize++ < curpos)
 		putc('\n', fp);
-}
+} /* save_globals() */
 
 /*
  * save_entry()
@@ -1256,9 +1383,7 @@ FILE *fp;
  * Returns 0 on success.
  */
 int
-save_entry(filename, pref)
-	char	*filename;
-	int	pref;
+save_entry(char *filename, int pref)
 {
 	FILE		*fp;
 	char		*buf;
@@ -1365,7 +1490,7 @@ save_entry(filename, pref)
 	fclose(fp);
 
 	return (0);
-}
+} /* save_entry() */
 
 /*
  * save()
