@@ -1,5 +1,5 @@
 /*
- * $Id: plat_sun.c,v 1.7 1999/03/07 08:36:40 dirk Exp $
+ * $Id: plat_sun.c,v 1.8 1999/05/05 16:09:49 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -26,7 +26,7 @@
  */
 
 #ifdef sun
-static char plat_sun_id[] = "$Id: plat_sun.c,v 1.7 1999/03/07 08:36:40 dirk Exp $";
+static char plat_sun_id[] = "$Id: plat_sun.c,v 1.8 1999/05/05 16:09:49 dirk Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -39,6 +39,9 @@ static char plat_sun_id[] = "$Id: plat_sun.c,v 1.7 1999/03/07 08:36:40 dirk Exp
 #include <sys/ioctl.h>
 
 #include "include/wm_config.h"
+#include "include/wm_helpers.h"
+#include "include/wm_cdrom.h"
+
 
 #include <ustat.h>
 #include <unistd.h>
@@ -463,9 +466,9 @@ gen_get_drive_status( struct wm_drive *d,
 	case CDROM_AUDIO_PAUSED:
 	case CDROM_AUDIO_INVALID:
 	case CDROM_AUDIO_NO_STATUS:
-		if (oldmode == PLAYING || oldmode == PAUSED)
+		if (oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_PAUSED)
 		{
-			*mode = PAUSED;
+			*mode = WM_CDM_PAUSED;
 			*track = sc.cdsc_trk;
 			*index = sc.cdsc_ind;
 			*pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
@@ -473,7 +476,7 @@ gen_get_drive_status( struct wm_drive *d,
 				sc.cdsc_absaddr.msf.frame;
 		}
 		else
-			*mode = STOPPED;
+			*mode = WM_CDM_STOPPED;
 		break;
 
 	/* CD ejected manually during play. */
@@ -481,11 +484,11 @@ gen_get_drive_status( struct wm_drive *d,
 		break;
 
 	case CDROM_AUDIO_COMPLETED:
-		*mode = TRACK_DONE; /* waiting for next track. */
+		*mode = WM_CDM_TRACK_DONE; /* waiting for next track. */
 		break;
 
-	default:
-		*mode = UNKNOWN;
+	default: 
+		*mode = WM_CDM_UNKNOWN;
 		break;
 	}
 
